(tryjupyter)=

# Try Jupyter

```{contents} Contents
:local:
```

These sections describe a few ways to get started with some of the most-commonly used tools in the Jupyter ecosystem.

## Try in Your Browser. No Installation Needed.


**Try Jupyter** (https://try.jupyter.org) is a site for trying out the Jupyter Notebook, equipped with kernels for several different languages (Julia, R, C++, Scheme, Ruby) without installing anything.
Click the link below to go to the page.

```{link-button} https://try.jupyter.org
:type: url
:text: Click to Try Jupyter
:classes: btn-primary
```

When running the examples on the `Try Jupyter` site, you will get a temporary Jupyter
server running on mybinder.org which you can use to play around until you close your
browser session.

You can use this site to try a few of the major interactive computing interfaces created by the Jupyter community.
A description of each is below.

### Try the Classic Notebook interface

The *Classic Notebook* interface is a document-oriented interface that allows you to create, view, and execute code in a Jupyter Notebook.

The example should look like this:

**Notebook Dashboard**

```{image} ../_static/_images/tryjupyter_file.png
```

**Notebook Editor**

```{image} ../_static/_images/trynb.png
```

### Try the JupyterLab interface

The Jupyter Lab interface is a more extensible and composable interactive computing interface for more complex workflows.

Here's an example of what the JupyterLab interface looks like:

```{image} ../_static/_images/jupyterlab.png
```

## Next step: install Jupyter locally

If you have tried Jupyter and like it, please use our [Installation Guide](install) to install Jupyter on your computer.

```{toctree}
:maxdepth: 2

../install
../running
```
